################################################################################
#                                Example
################################################################################
library(Iso)
library(survival)
library(fastmatch)
library(SQUAREM)
library(doBy)

source("function_SIM.R")

# Generate a dataset
set.seed(2020)
N <- 800
P <- 3
beta0 <- c(-1,1,-1)
X <- matrix(rnorm(N*P), ncol = P, nrow = N)
z0 <- X%*%beta0
r0 <- exp(abs(z0)^(1/3)*sign(z0))
T <- rweibull(N,shape=2,scale=sqrt(r0))
C <- rexp(N, .25)
Y <- pmin(T,C)
E <- T<=C
tau <- 2.5
ltau <- tau^2
E[Y>tau] <- 0
Y <- (pmin(Y,tau))

# Create the input of the SIM function
ldata <- data.frame(X = X, Y = Y, E = E)
zz <- seq(from = -1, to = 1, length = 100)
tt <- seq(from = 0, to = tau, length = 100)

# Run the SIM function, 20 additional initial values are tried
fit <- SIM(ldata, 20, zz, tt)

# Results
fit$beta # true value is (-0.5773503,0.5773503,-0.5773503)

op <- par(mfrow = c(1,2))
plot(tt, fit$Ltt)
points(tt, tt^2/ltau, col = 2) # true value

plot(zz, fit$rzz)
points(zz, exp(abs(zz)^(1/3)*sign(zz))/ltau, col = 2) # true value
par(op)
