library(Iso)
library(doBy)
library(survival)
library(fastmatch)
library(SQUAREM)
library(mfp)
library(tidyverse)

source("function_SIM.R")

data("GBSG")
t0 <- 365.25*6

ldata <- GBSG %>%
  mutate(Y = rfst,
         E = cens,
         E = ifelse(Y > t0, 0, E),
         Y = ifelse(Y > t0, t0, Y)) %>%
  mutate_at(.vars = c("tumsize", "posnodal"), scale) %>%
  select(htreat, tumsize, tumgrad, posnodal,
         Y, E)
ldata <- model.matrix(~., data = ldata)[,-1]
ldata <- data.frame(ldata)

tau <- max(ldata$Y)
zz <- seq(from = -5, to = 1, length = 10000)
tt <- c(0,sort(ldata$Y))
set.seed(2020)

fit <- SIM(ldata, 50, zz, tt)
fit$beta


N <- dim(ldata)[1]
res <- matrix(ncol = 5, nrow = 500)
set.seed(2020)

for(l in 1:500)
{
  res[l,] <- SIM(ldata[sample(1:N, N, replace = TRUE), ], 50, zz, tt)$beta
  print(l)
}

fit.cox <- coxph(Surv(Y,E)~., data = ldata)
fit.cox$coefficients/sqrt(sum(fit.cox$coefficients^2))

# Table 3
round(cbind(-fit$beta,
      apply(-res, 2, function(x) quantile(x, probs = 0.025)),
      apply(-res, 2, function(x) quantile(x, probs = 0.975)),
      fit.cox$coefficients/sqrt(sum(fit.cox$coefficients^2))),3)


pdf("Lambda.pdf",5,5)
plot((tt),fit$Ltt,
     type = "s", ylab = "Lambda(t)", xlab = "t (days)",
     lwd = 2)
dev.off()

pdf("phi.pdf",5,5)
plot(zz[zz>-3], -log(fit$rzz[zz>-3]),
     type = "s", ylab = expression(paste(phi,"(z)")), xlab = "z",
     lwd = 2)
dev.off()



ind <- ldata$tumgrad3 == 1
h1 <- c(0, median(ldata$tumsize[ind]),
        0,1, median(ldata$posnodal[ind]))
h2 <- c(1, median(ldata$tumsize[ind]),
        0,1, median(ldata$posnodal[ind]))
df <- data.frame(rbind(h1,h2))
colnames(df) <- varname
lp <- predict(fit.cox, newdata = df)
hazCox <- basehaz(fit.cox)
hazmat <- matrix(ncol = 2, nrow = length(hazCox$time))
for(j in 1:2)
{
  hazmat[,j] <- hazCox$hazard*exp(lp[j])
}

phi.est <- -log(fit$rzz)
phi.fun <- stepfun(x = zz,
                   y = c(phi.est, tail(phi.est,1)))
zsc <- as.matrix(df)%*%as.vector(fit$beta)
phizsc <- phi.fun(zsc)
hazmat2 <- matrix(ncol = 2, nrow = length(tt))

for(j in 1:2)
{
  hazmat2[,j] <- fit$Ltt*exp(phizsc[j])
}
pdf("surv.pdf",5,5)
plot(hazCox$time, exp(-(hazmat[,1])),
     type = "s", xlim = c(0,tau), ylim = c(0.2,1), lty = 2,
     ylab = "Survival Probability", xlab = "t (days)", col = "darkred")
points(hazCox$time, exp(-(hazmat[,2])), type = "s", col = "darkred")
points(tt, exp(-(hazmat2[,1])),
       type = "s", col = 1, lty = 2)
points(tt, exp(-(hazmat2[,2])), type = "s", col = 1)
dev.off()

